.. _commands:

Command Palette
---------------

All user actions in JupyterLab are processed through a centralized
command system. These commands are shared and used throughout JupyterLab
(menu bar, context menus, keyboard shortcuts, etc.). The command palette
in the left sidebar provides a keyboard-driven way to search for and run
JupyterLab commands:

.. image:: images/command_palette.png
   :align: center
   :class: jp-screenshot

.. _access-palette:

The command palette can be accessed using the keyboard shortcut
``Command/Ctrl Shift C``:

.. raw:: html

  <div class="jp-youtube-video">
     <iframe src="https://www.youtube-nocookie.com/embed/lPuj57UkxYs?rel=0&amp;showinfo=0" frameborder="0" allow="autoplay; encrypted-media" allowfullscreen></iframe>
  </div>
